@@ -55,7 +55,7 @@ def run_cli(filename, template, rules, regions, override_spec, build_graph, regi
         for path in registry_schemas:
             if path and os.path.isdir(os.path.expanduser(path)):
                 for f in os.listdir(path):
-                    with open(os.path.join(path, f)) as schema:
+                    with open(os.path.join(path, f), encoding='utf-8') as schema:
                         REGISTRY_SCHEMAS.append(json.load(schema))
 
     return run_checks(filename, template, rules, regions, mandatory_rules)
